@@ -2,14 +2,21 @@ package Apache::No404Proxy::Google;
 
 use strict;
 use vars qw($VERSION);
-$VERSION = '0.01';
+$VERSION = 0.05;
 
-use WWW::Cache::Google;
+require Apache::No404Proxy;
 use base qw(Apache::No404Proxy);
 
-sub translate {
-    my($class, $uri) = @_;
-    return WWW::Cache::Google->new($uri)->as_string;
+use SOAP::Lite;
+
+sub fetch {
+    my($class, $r) = @_;
+    my $key = $r->dir_config('GoogleLicenseKey') or die "You need GoogleLicenseKey to use this module";
+    return SOAP::Lite
+	->uri('urn:GoogleSearch')
+	    ->proxy('http://api.google.com/search/beta2')
+		->doGetCachedPage($key, $r->uri)
+		    ->result;
 }
 
 1;
@@ -23,20 +30,12 @@ Apache::No404Proxy::Google - Implementation of Apache::No404Proxy
 
   # in httpd.conf
   PerlTransHandler Apache::No404Proxy::Google
+  PerlSetVar GoogleLicenseKey **************
 
 =head1 DESCRIPTION
 
 Apache::No404Proxy::Google is one of the implementations of
-Apache::No404Proxy. This module uses WWW::Cache::Google to translate
-URI to Google cache.
-
-See L<Apache::No404Proxy/"SUBCLASSING"> for using other cache archive on
-the web other than Google.
-
-=head1 CAVEAT
-
-See L<Apache::No404Proxy/"RESTRICTIONS FOR USE"> before using it. If
-you have not done, B<DO IT NOW!>
+Apache::No404Proxy. This module uses SOAP::Lite to fetch Google cache.
 
 =head1 AUTHOR
 
@@ -47,6 +46,6 @@ it under the same terms as Perl itself.
 
 =head1 SEE ALSO
 
-L<Apache::No404Proxy>, L<WWW::Cache::Google>
+L<Apache::No404Proxy>, L<SOAP::Lite>, L<WWW::Cache::Google>
 
 =cut
